
try {
  new Function("import('/hacsfiles/frontend/e.4add7a3d.js')")();
} catch (err) {
  var el = document.createElement('script');
  el.src = '/hacsfiles/frontend/e.4add7a3d.js';
  document.body.appendChild(el);
}
  